@@ -32,15 +32,8 @@ class LanguageSelectorServer(dbus.service.Object):
                                     "/org/freedesktop/PolicyKit1/Authority",
                                     "org.freedesktop.PolicyKit1.Authority")
         policykit = dbus.Interface(obj, "org.freedesktop.PolicyKit1.Authority")
-        info = dbus.Interface(connection.get_object('org.freedesktop.DBus',
-                                              '/org/freedesktop/DBus/Bus',
-                                              False),
-                              'org.freedesktop.DBus')
-        pid = info.GetConnectionUnixProcessID(sender)
-        subject = ('unix-process',
-                   { 'pid' : dbus.UInt32(pid, variant_level=1),
-                     'start-time' : dbus.UInt64(0),
-                   }
+        subject = ('system-bus-name',
+                   { 'name': dbus.String(sender, variant_level = 1) }
                   )
         details = { '' : '' }
         flags = dbus.UInt32(1) #   AllowUserInteraction = 0x00000001
